@@ -1,7 +1,7 @@
-__version__ = "0.13.5"
+__version__ = "0.15.2"
 
 
-def add_config_paths(verbose: bool = True):
+def add_config_paths(verbose: bool = False):
     # Support all config paths
     # Add config paths
     import sys
