@@ -34,11 +34,13 @@ class StableEngine(AbstractEngine):
         self._show_progress_bar = kwargs.pop("show_progress_bar", True)
 
     def chunk_documents(self, documents: DocumentList):
-        num_chunks = self.pull_chunksize // self._transform_chunksize + 1
+        num_chunks = len(documents) // self._transform_chunksize + 1
         for i in range(num_chunks):
             start = i * self._transform_chunksize
             end = (i + 1) * self._transform_chunksize
-            yield documents[start:end]
+            chunk = documents[start:end]
+            if len(chunk) > 0:
+                yield chunk
 
     def _filter_for_non_empty_list(self, docs: DocumentList):
         # if there are more keys than just _id in each document
